SplitSessionState enum

The current state of a split payment session.

Inheritance
Available extensions

Values

initial → const SplitSessionState

No payments have been made yet.

partiallyPaid → const SplitSessionState

At least one payment has been made but outstanding > 0.

fullyPaid → const SplitSessionState

Outstanding amount is <= 0 (fully paid or surplus).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SplitSessionState>
A constant List of the values in this enum, in order of their declaration.