SplitRefundComplete class

Inheritance

Constructors

SplitRefundComplete({required double refundAmount, required String paymentType, String? refundEventId, required String parentEventId, required bool success, String? errorMessage, String? lastRefundId})
const

Properties

errorMessage String?
final
hashCode int
The hash code for this object.
no setterinherited
lastRefundId String?
final
parentEventId String
final
paymentType String
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
refundAmount double
final
refundEventId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
success bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited