onRefundComplete property

Future<void> Function(String refundId)? onRefundComplete
final

Optional callback invoked with the refund ID after a successful backend refund. Used by the merchant app to navigate to RefundCompletePage for receipt/SMS/email instead of the default SplitRefundCompleteView.

The callback is awaited before this screen pops, so the consumer can perform async work (e.g. fetching the updated transaction and pushing RefundCompletePage) before control returns here.

Implementation

final Future<void> Function(String refundId)? onRefundComplete;