apiClient property
Optional API client for backend communication. When provided, the service can fetch and synchronise state from the backend. In unit tests this can be omitted.
Implementation
final SplitPaymentApiClient? apiClient;
Optional API client for backend communication. When provided, the service can fetch and synchronise state from the backend. In unit tests this can be omitted.
final SplitPaymentApiClient? apiClient;