SurplusBehavior enum

Controls how the split flow handles surplus payments.

Inheritance
Available extensions

Values

block → const SurplusBehavior

Surplus is always blocked — user is shown an info dialog and returned to Keypad.

blockWithExplicitTip → const SurplusBehavior

Surplus is blocked only when an explicit (order-level) tip is present; otherwise a confirmation dialog is shown.

dialog → const SurplusBehavior

Surplus is allowed after a confirmation dialog (default).

silent → const SurplusBehavior

Surplus is allowed silently — no dialog shown.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SurplusBehavior>
A constant List of the values in this enum, in order of their declaration.