disableCard property
When true, renders content without the outer Card wrapper. Used when this tile is embedded inside an ExpansionTile.
Implementation
final bool disableCard;
When true, renders content without the outer Card wrapper. Used when this tile is embedded inside an ExpansionTile.
final bool disableCard;